LedgerKeyShared

Struct LedgerKeyShared 

pub struct LedgerKeyShared<LK: LedgerKey> { /* private fields */ }

Implementations

Source

impl LedgerKeyShared<LedgerHidKey>

pub fn instance() -> Result<LedgerKeyShared<LedgerHidKey>, HWKeyError>

Get (or create on the first call) a shared instance to access LedgerKey

Source

impl<LK: LedgerKey> LedgerKeyShared<LK>

An instance of LedgerKey that can be safely used between different threads because it opens the device and executes all commands in its own thread. This is important on macOS where the HID device is not thread safe (and sometimes it even needs to “sleep” between uses from different threads, so a Mutex doesn’t always help), and when a HID device is used improperly it could panic with SIGILL.

pub fn is_connected(&self) -> bool